<?php
/*
Plugin Name: Slideshow
Plugin URI: http://github.com/johanson/slideshow
Description: Slideshow
Version: 1.0
Author: Rasmus Johanson
Author URI: http://github.com/johanson
License: GPLv2

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
*/

global $table_name;
global $wpdb;

// Define table name for plugin (with prefix)
$table_name = $wpdb->prefix . 'slideshow_plugin';

// Get's called when plugin is installed or reinstalled
register_activation_hook(__FILE__, 'first_install');

function first_install() {
	global $wpdb, $table_name;

	// Create a table to database
	$sql = "CREATE TABLE .$table_name (
		id int(11) NOT NULL AUTO_INCREMENT,
		thumbnail_url varchar(1024) NOT NULL,
		url varchar(1024) NOT NULL,
		link varchar(1024) NOT NULL DEFAULT 'http://',
		description varchar(5120) NOT NULL,
		position int(11) NOT NULL,
		UNIQUE KEY id (id)
	);";

	require_once(ABSPATH . 'wp-admin/includes/upgrade.php');
	dbDelta($sql);

	// Create default settings
	$default_settings = array(
		"fx" => "rain",
		"delay" => "3000",
		"navigation" => "true",
		"hoverPause" => "true",
		"width" => "640",
		"height" => "480",
		"jsmanually" => "false",
		"cssmanually" => "false");

	delete_option('slideshow_option');
	update_option('slideshow_option', $default_settings);
}

// Create Admin menu
add_action('admin_menu', 'slideshow_plugin_menu');

function slideshow_plugin_menu() {
	add_menu_page('Slideshow Options', 'Slideshow', 'manage_options', 'slideshow-manager', 'slideshow_manager_options', plugin_dir_url( __FILE__ ).'icon.png', 5);
}


add_action('admin_init', 'settings_init');

// Register settings, internationalization
function settings_init() {
	register_setting('slideshow_plugin_options', 'slideshow_option', 'slideshow_settings_validate');
	// Tnternationalization
	load_plugin_textdomain('slideshow', false, dirname(plugin_basename(__FILE__)) . '/localization/' );
}

// Validate checkboxes, trust the rest
function slideshow_settings_validate($input) {
	$input['jsmanually'] = ($input['jsmanually'] == 'true' ? 'true' : 'false');
	$input['cssmanually'] = ($input['cssmanually'] == 'true' ? 'true' : 'false');
	$input['navigation'] = ($input['navigation'] == 'true' ? 'true' : 'false');
	$input['hoverPause'] = ($input['hoverPause'] == 'true' ? 'true' : 'false');
	return $input;
}

add_action('admin_init', 'register_scripts_backend');

// Enqueue backend scripts
function register_scripts_backend() {
	wp_enqueue_script('jquery');
	wp_enqueue_script('jquery-ui-sortable');
}

add_action('wp_enqueue_scripts', 'register_nivo');

// Enqueue Coin-Slider JavaScript and CSS
function register_nivo() {
	$options = get_option('slideshow_option', 'slideshow');
	wp_enqueue_script('jquery');
	if ($options['jsmanually'] != "true") {
		wp_register_script('coin-slider', plugins_url('coin-slider/coin-slider.min.js', __FILE__) );
		wp_enqueue_script('coin-slider');
	}
	if ($options['cssmanually'] != "true") {
		wp_register_style('coin-css', plugins_url('coin-slider/coin-slider-styles.css', __FILE__) );
		wp_enqueue_style('coin-css');
	}
}


add_action('admin_head', 'backend_javascript');

// Add JavaScript to backend
function backend_javascript() { ?>
<script type="text/javascript">
jQuery(document).ready(function($) {

	jQuery(".sortableTable").sortable({
		handle : '.slideshow_thumb',
		update: function() {
			jQuery(".slideshow_thumb").hide();
			var data = {
				action: 'sort',
				pages: jQuery('.sortableTable').sortable('serialize')
			};
			jQuery.post(ajaxurl, data, function(data) {
				jQuery(".slideshow_thumb").show();
				console.log(data);
			});
		}
	});

	jQuery(".delete_button").click(function (e) {
			e.preventDefault();
			var ask = confirm('<?php _e('Are you sure you want to delete slide?', 'slideshow'); ?>');
			if (ask == false) {
				return false;
			}

			var id = jQuery(this).attr("id").substring(7);

			var data = {
				action: 'delete',
				id: id
			};
			jQuery.post(ajaxurl, data, function(data) {
				console.log(data);
			});

			jQuery(this).closest('tr').hide();
	});

	jQuery(".update_button").click(function (e) {
			e.preventDefault();

			var id = jQuery(this).attr("id").substring(7);
			var description = jQuery("#description_"+id).val();
			var link = jQuery("#link_"+id).val();
			jQuery("#description_"+id+", #link_"+id).hide();

			var data = {
				action: 'update',
				id: [id, description, link]
			};
			jQuery.post(ajaxurl, data, function(data) {
				console.log(data);
				jQuery("#description_"+id+", #link_"+id).show();
			});

	});

	jQuery("#advanced-settings-toggle").click(function(e) {
		e.preventDefault();
		jQuery("#advanced-settings-panel").toggle();
	});

});
</script>
<?php
}

add_action('wp_ajax_sort', 'sort_callback');
add_action('wp_ajax_delete', 'delete_callback');
add_action('wp_ajax_update', 'update_callback');

function sort_callback() {
	global $wpdb, $table_name;
	parse_str($_POST['pages'], $pageOrder);
	foreach ($pageOrder['page'] as $key => $value) {
		$wpdb->update($table_name, array('position' => $key), array('id' => $value));
	}
	die(); // Required to return a proper result (http://codex.wordpress.org/AJAX_in_Plugins)
}

function delete_callback() {
	global $wpdb, $table_name;
	$id = $_POST['id'];
	$wpdb->query("DELETE FROM $table_name WHERE id = $id");
	die();
}

function update_callback() {
	global $wpdb, $table_name;
 	$data = $_POST['id'];
 	$wpdb->update($table_name, array('description' => $data[1], 'link' => $data[2]), array('id' => $data[0]));
 	print_r($data);
	die();
}

function slideshow_upload() {
	global $wpdb, $table_name;
	$options = get_option('slideshow_option', 'slideshow');

	$upload = wp_handle_upload($_FILES['async-upload'], 0);
	$url = $upload['url'];
	$file = $upload['file'];
	$type = $upload['type'];

	// Get upload dir
	$upload_dir = str_replace(basename($file), '', $url);

	if(!($type == "image/gif" || $type == "image/jpeg" || $type == "image/png")) {
		echo '<div class="error" id="message"><p>';
		_e("Wrong file type!");
		echo '</p></div>';
		return;
	}

	list($width, $height) = getimagesize($file);
	// Check width/height requirements
	if($width < $options['width'] || $height < $options['height']) {
		echo '<div class="error" id="message"><p>';
		_e("The picture you uploaded is too small!");
		echo '</p></div>';
		return;
	}

	// If image is too big, scale it down
	if($width < $options['width'] || $height > $options['height']) {
		// Resize the image, image proposition comes from settings
		$resized = image_resize($file, $options['width'], $options['height'], true, 'resized');
		$resized_url = $upload_dir . basename($resized);
		unlink($file);
	}

	if(isset($upload['file'])) {
		// Create thumbnail width="100" height="75"
		$thumbnail = image_resize($file, 100, 75, true, 'thumb');
		$thumbnail_url = $upload_dir . basename($thumbnail);
	}

	$wpdb->insert($table_name, array('url' => $url, 'thumbnail_url' => $thumbnail_url, 'description' => '', 'position' => '1000'));
	echo '<div class="updated" id="message"><p>';
	_e("Image uploaded successfully");
	echo '</p></div>';
}

function slideshow_manager_options() {
	global $wpdb, $table_name;

	if($_REQUEST['action'] == 'wp_handle_upload') {
		slideshow_upload(); 
	}

?>

<div class="wrap">
<h2>Slideshow</h2>

<table class="widefat" id="slideshowtable">
<thead>
	<tr>
		<th style="width: 100px;"><?php _e('Thumbnail', 'slideshow'); ?></th>
		<th><?php _e('Caption and link address', 'slideshow'); ?></th>
		<th style="width: 65px;"></th>
		<th style="width: 65px;"></th>
	</tr>
</thead>
<tfoot>
<form enctype="multipart/form-data" action="?page=slideshow-manager" method="post">
<input type="hidden" name="action" id="action" value="wp_handle_upload" />
	<tr>
		<th colspan="3">
			<input type="file" name="async-upload" id="async-upload" style="width: 100%;">
		</th>
		<th style="width: 65px; text-align: center;">
			<input type="submit" name="html-upload" id="html-upload" class="button" value="<?php _e('Upload', 'slideshow'); ?>" style="font-family: sans-serif; font-size: 12px; line-height: 15px; padding: 3px 10px;">
		</th>
	</tr>
</form>

</tfoot>
<tbody class="sortableTable">

<?php
$myrows = $wpdb->get_results("SELECT * FROM $table_name ORDER BY position ASC"); // order by
foreach ($myrows as $row) {
?>
	<tr id="page_<?php echo $row->id; ?>">
		<td style="background: url(<?php echo get_admin_url(); ?>images/loading.gif) center no-repeat;">
			<img src="<?php echo $row->thumbnail_url; ?>" width="100" height="75" alt="thumbnail" class="slideshow_thumb" style="cursor: move;">
		</td>
		<td style="background: url(<?php echo get_admin_url(); ?>images/loading.gif) center no-repeat;">
			<textarea id="description_<?php echo $row->id; ?>" style="width: 100%; height: 45px;"><?php echo $row->description; ?></textarea>
			<input type="text" id="link_<?php echo $row->id; ?>" style="width: 100%; height: 25px;" value="<?php echo $row->link; ?>">
		</td>
		<td style="vertical-align: middle; text-align: center;">
			<a class="button-primary update_button" id="update_<?php echo $row->id; ?>" href="#"><?php _e('Update', 'slideshow'); ?></a>
		</td>
		<td style="vertical-align: middle; text-align: center;">
			<a class="button delete_button" id="delete_<?php echo $row->id; ?>" href="#"><?php _e('Delete', 'slideshow'); ?></a>
		</td>
	</tr>

<?php
}
?>

</tbody>
</table>

<h3><?php _e('Slideshow Settings', 'slideshow'); ?></h3>
<div id="slideshow-settings-panel" style="background: #F9F9F9; border: 1px solid #DFDFDF; padding-bottom: 8px;">
	<form method="post" action="options.php">
		<?php settings_fields('slideshow_plugin_options', 'slideshow'); ?>
		<?php $options = get_option('slideshow_option', 'slideshow'); ?>
		<table class="form-table">
			<tr valign="top" style="border-bottom: 1px solid #DFDFDF;">
			<th scope="row"><?php _e('Slide transition effect', 'slideshow'); ?></th>
			<td>
				<select name="slideshow_option[fx]">
					<option <?php selected('swirl', $options['fx']); ?>>swirl</option>
					<option <?php selected('rain', $options['fx']); ?>>rain</option>
					<option <?php selected('straight', $options['fx']); ?>>straight</option>
					<option <?php selected('random', $options['fx']); ?>>random</option>
				</select>
			</td>
			</tr>

			<tr valign="top" style="border-bottom: 1px solid #DFDFDF;">
				<th scope="row"><?php _e('Delay between slides', 'slideshow'); ?></th>
				<td><input type="number" name="slideshow_option[delay]" value="<?php echo $options['delay']; ?>"><span class="description" style="margin-left: 10px;"><?php _e('In milliseconds', 'slideshow'); ?></span></td>
			</tr>

			<tr valign="top" style="border-bottom: 1px solid #DFDFDF;">
				<th scope="row"><?php _e('Enable navigation', 'slideshow'); ?></th>
				<td>
					<input name="slideshow_option[navigation]" type="checkbox" value="true" <?php checked('true', $options['navigation']); ?>> 
				</td>
			</tr>

			<tr valign="top" style="border-bottom: 1px solid #DFDFDF;">
				<th scope="row"><?php _e('Pause slideshow on hover', 'slideshow'); ?></th>
				<td>
					<input name="slideshow_option[hoverPause]" type="checkbox" value="true" <?php checked('true', $options['hoverPause']); ?>> 
				</td>
			</tr>

		</table>
</div>

<h3><?php _e('Advanced Settings', 'slideshow'); ?> (<a href="#" id="advanced-settings-toggle" style="text-decoration: none;"><?php _e('Show', 'slideshow'); ?></a>)</h3>
<div class="hidden" id="advanced-settings-panel" style="background: #F9F9F9; border: 1px solid #DFDFDF; padding-bottom: 8px;">
	<table class="form-table"	>
		<tr valign="top" style="border-bottom: 1px solid #DFDFDF;">
			<th scope="row"><?php _e('Slideshow width', 'slideshow'); ?></th>
			<td><input type="number" name="slideshow_option[width]" value="<?php echo $options['width']; ?>"><span class="description" style="margin-left: 10px;"><?php _e('In pixels', 'slideshow'); ?></span></td>
		</tr>
		<tr valign="top" style="border-bottom: 1px solid #DFDFDF;">
			<th scope="row"><?php _e('Slideshow height', 'slideshow'); ?></th>
			<td><input type="number" name="slideshow_option[height]" value="<?php echo $options['height']; ?>"><span class="description" style="margin-left: 10px;"><?php _e('In pixels', 'slideshow'); ?></span></td>
		</tr>

		<tr valign="top" style="border-bottom: 1px solid #DFDFDF;">
			<th scope="row"><?php _e('I want to add slider.js manually', 'slideshow'); ?></th>
			<td>
				<input name="slideshow_option[jsmanually]" type="checkbox" value="true" <?php checked('true', $options['jsmanually']); ?>> 
			</td>
		</tr>
		<tr valign="top" style="border-bottom: 1px solid #DFDFDF;">
			<th scope="row"><?php _e('I want to add slider.css manually', 'slideshow'); ?></th>
			<td>
				<input name="slideshow_option[cssmanually]" type="checkbox" value="true" <?php checked('true', $options['cssmanually']); ?>> 
			</td>
		</tr>
	</table>
</div>

<p class="submit"><input type="submit" class="button-primary" value="<?php _e('Save Settings', 'slideshow'); ?>" /></p>
</form>

</div>

<?php
}

add_shortcode('slideshow', 'slideshow');

function slideshow() {
global $wpdb, $table_name;
$options = get_option('slideshow_option');
?>

<script type="text/javascript">
jQuery(document).ready(function($) {
	$('#coin-slider').coinslider({ 
		effect: '<?php echo $options['fx']; ?>',
		width: <?php echo $options['width']; ?>,
		height: <?php echo $options['height']; ?>,
		spw: 7,
		sph: 5,
		delay: <?php echo $options['delay']; ?>,
		sDelay: 30,
		opacity: 1,
		titleSpeed: 500,
		links : true,
		navigation: <?php echo $options['navigation']; ?>,
		hoverPause: <?php echo $options['hoverPause']; ?>

	});
});
</script>

<div id="coin-slider">
<?php
$myrows = $wpdb->get_results("SELECT * FROM $table_name ORDER BY position ASC"); // order by
foreach ($myrows as $row) {
	echo url('start', $row->link);
	echo '<img src="'.$row->url.'" alt="'.$row->description.'" />';
	echo "\n";
	echo '<span>'.$row->description.'</span>';
	echo "\n";
	echo url('end', '');
}
?>
</div>
<?php
}

function url($var1, $var2){

	if($var2 == 'http://' || $var2 == '') {
		$output = '<a href="javascript:void(0);">'. 
		"\n";
	}

	if($var1 == 'start') {
		if($var2 == 'http://' || $var2 == '') {
			$output = '<a href="javascript:void(0);">'. 
			"\n";
		} else {
			$output = '<a href="'.$var2.'">'. 
			"\n";
		}
	}
	if($var1 == 'end') {
		$output = '</a>'. 
		"\n";
	}

	return $output;
}
?>